# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from team_member_server_sdk.models.action_code import ActionCode
from team_member_server_sdk.models.action_operation import ActionOperation

class ActionToUpdate(BaseModel):
    """
    ActionToUpdate
    """
    action_code: ActionCode = Field(...)
    operation: ActionOperation = Field(...)
    __properties = ["action_code", "operation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ActionToUpdate:
        """Create an instance of ActionToUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ActionToUpdate:
        """Create an instance of ActionToUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ActionToUpdate.parse_obj(obj)

        _obj = ActionToUpdate.parse_obj({
            "action_code": obj.get("action_code"),
            "operation": obj.get("operation")
        })
        return _obj


